# -*- coding: utf-8 -*-

import configparser

import pymysql

from ydl_ai_recommender.src.utils.log import create_logger


class MySQLClient():

    def __init__(self, host, port, user, password) -> None:
        self.logger = create_logger(__name__, 'mysql_client.log', is_rotating=True)
        self.connection = pymysql.connect(
            host=host,
            port=port,
            user=user,
            password=password,
            charset='utf8mb4',
            cursorclass=pymysql.cursors.DictCursor
        )
        self.cursor = self.connection.cursor()
        self._log_info('数据库连接成功')

    def _connect(self):
        self.connection = pymysql.connect(
            host=self.host,
            port=self.port,
            user=self.user,
            password=self.password,
            charset='utf8mb4',
            cursorclass=pymysql.cursors.DictCursor
        )
        self.cursor = self.connection.cursor()
        self._log_info('数据库连接成功')

    def _log_info(self, text, *args, **params):
        if self.logger:
            self.logger.debug(text, *args, **params)

    def query(self, sql):
        if self.cursor is None:
            self._connect()

        # sql += ' limit 1000'
        self._log_info('begin execute sql: %s', sql)
        row_count = self.cursor.execute(sql)
        data = self.cursor.fetchall()
        self._log_info('fetch row count: %s', row_count)
        return row_count, data

    def __del__(self):
        try:
            self.cursor.close()
            self.connection.close()
            self._log_info('dataset disconnected')
        except Exception as e:
            print(e)

    @classmethod
    def create_from_config_file(cls, config_file, section='ADB'):
        config = configparser.RawConfigParser()
        config.read(config_file)
        return cls(
            config.get(section, 'host'),
            config.getint(section, 'port'),
            config.get(section, 'user'),
            config.get(section, 'password')
        )